@@ -28,8 +28,12 @@ MEDIA_URL = getattr(settings, "FILEBROWSER_MEDIA_URL", settings.MEDIA_URL)
 # DO NOT USE A SLASH AT THE BEGINNING, DO NOT FORGET THE TRAILING SLASH AT THE END.
 DIRECTORY = getattr(settings, "FILEBROWSER_DIRECTORY", 'uploads/')
 
+_uploads_dir = os.path.join(MEDIA_ROOT, DIRECTORY)
+if not os.path.exists(_uploads_dir):
+    os.makedirs(_uploads_dir)
+
 # The URL/PATH to your filebrowser media-files.
-URL_FILEBROWSER_MEDIA = getattr(settings, "FILEBROWSER_URL_FILEBROWSER_MEDIA", "/media/filebrowser/")
+URL_FILEBROWSER_MEDIA = getattr(settings, "FILEBROWSER_URL_FILEBROWSER_MEDIA", "%sfilebrowser/" % settings.STATIC_URL)
 PATH_FILEBROWSER_MEDIA = getattr(settings, "FILEBROWSER_PATH_FILEBROWSER_MEDIA", os.path.join(settings.MEDIA_ROOT, 'filebrowser/'))
 
 # The URL/PATH to your TinyMCE Installation.
@@ -65,23 +69,25 @@ SELECT_FORMATS = getattr(settings, "FILEBROWSER_SELECT_FORMATS", {
 # VERSION URL: VERSIONS_BASEDIR/original_path/originalfilename_versionsuffix.extension
 VERSIONS_BASEDIR = getattr(settings, 'FILEBROWSER_VERSIONS_BASEDIR', '')
 # Versions Format. Available Attributes: verbose_name, width, height, opts
-VERSIONS = getattr(settings, "FILEBROWSER_VERSIONS", {
-    'fb_thumb': {'verbose_name': 'Admin Thumbnail', 'width': 60, 'height': 60, 'opts': 'crop upscale'},
-    'thumbnail': {'verbose_name': 'Thumbnail (140px)', 'width': 140, 'height': '', 'opts': ''},
-    'small': {'verbose_name': 'Small (300px)', 'width': 300, 'height': '', 'opts': ''},
-    'medium': {'verbose_name': 'Medium (460px)', 'width': 460, 'height': '', 'opts': ''},
-    'big': {'verbose_name': 'Big (620px)', 'width': 620, 'height': '', 'opts': ''},
-    'cropped': {'verbose_name': 'Cropped (60x60px)', 'width': 60, 'height': 60, 'opts': 'crop'},
-    'croppedthumbnail': {'verbose_name': 'Cropped Thumbnail (140x140px)', 'width': 140, 'height': 140, 'opts': 'crop'},
-})
+VERSIONS = getattr(settings, "FILEBROWSER_VERSIONS", {})
+
+# VERSIONS = getattr(settings, "FILEBROWSER_VERSIONS", {
+#     'fb_thumb': {'verbose_name': 'Admin Thumbnail', 'width': 60, 'height': 60, 'opts': 'crop upscale'},
+#     'thumbnail': {'verbose_name': 'Thumbnail (140px)', 'width': 140, 'height': '', 'opts': ''},
+#     'small': {'verbose_name': 'Small (300px)', 'width': 300, 'height': '', 'opts': ''},
+#     'medium': {'verbose_name': 'Medium (460px)', 'width': 460, 'height': '', 'opts': ''},
+#     'big': {'verbose_name': 'Big (620px)', 'width': 620, 'height': '', 'opts': ''},
+#     'cropped': {'verbose_name': 'Cropped (60x60px)', 'width': 60, 'height': 60, 'opts': 'crop'},
+#     'croppedthumbnail': {'verbose_name': 'Cropped Thumbnail (140x140px)', 'width': 140, 'height': 140, 'opts': 'crop'},
+# })
 # Versions available within the Admin-Interface.
 ADMIN_VERSIONS = getattr(settings, 'FILEBROWSER_ADMIN_VERSIONS', ['thumbnail','small', 'medium','big'])
 # Which Version should be used as Admin-thumbnail.
 ADMIN_THUMBNAIL = getattr(settings, 'FILEBROWSER_ADMIN_THUMBNAIL', 'fb_thumb')
 
 # EXTRA SETTINGS
-# True to save the URL including MEDIA_URL to your model fields
-# or False (default) to save path relative to MEDIA_URL.
+# True to save the URL including STATIC_URL to your model fields
+# or False (default) to save path relative to STATIC_URL.
 # Note: Full URL does not necessarily means absolute URL.
 SAVE_FULL_URL = getattr(settings, "FILEBROWSER_SAVE_FULL_URL", True)
 # If set to True, the FileBrowser will not try to import a mis-installed PIL.
